@@ -1,14 +1,13 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2023, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
 
 require 'sus/fixtures/async/reactor_context'
 
 require 'async/http/server'
 require 'async/http/client'
 require 'async/http/endpoint'
-require 'async/io/shared_endpoint'
 
 module Sus::Fixtures
 	module Async
@@ -100,7 +99,7 @@ module Sus::Fixtures
 					super
 					
 					# We bind the endpoint before running the server so that we know incoming connections will be accepted:
-					@bound_endpoint = ::Async::IO::SharedEndpoint.bound(endpoint)
+					@bound_endpoint = endpoint.bound
 					
 					@server_endpoint = make_server_endpoint(@bound_endpoint)
 					mock(@server_endpoint) do |wrapper|
@@ -127,10 +126,13 @@ module Sus::Fixtures
 					@client = make_client(@client_endpoint)
 				end
 				
-				def after
-					@client&.close
-					@server_task&.stop
-					@bound_endpoint&.close
+				def after(error = nil)
+					# We add a timeout here, to avoid hanging in `@client.close`:
+					::Async::Task.current.with_timeout(1) do
+						@client&.close
+						@server_task&.stop
+						@bound_endpoint&.close
+					end
 					
 					super
 				end
